% Script to plot time evolution of four vortices near a wall.


close all
clear all
clc

% Setting timestep between 0 and 100s with an interval of .01s.
tArray = [0:0.01:10]';

% Setting circulation to 1 and constant b to 1.
gamma = 1;
b = 1;


% Setting constant lilG, a constant multiplier of Gamma.
lilG = 0.2;

% Setting vortexArray, where (:,1) is x coord, (,2) is y coord, and
% (:,3) is gamma.

% The last four vortices, which have opposite gamma values, are there to
% enforce the presence of a wall according to method of images.
vortexArray = [(-b/2)  (b/2) (-gamma);         ...
    (-b/4)  (b/2) (-lilG)*( gamma); ...
    ( b/4)  (b/2) ( lilG)*( gamma); ...
    ( b/2)  (b/2) ( gamma);         ...
    (-b/2) (-b/2) ( gamma);         ...
    (-b/4) (-b/2) ( lilG)*( gamma); ...
    ( b/4) (-b/2) (-lilG)*( gamma); ...
    ( b/2) (-b/2) (-gamma)];



% TL is size(tArray) - 1 to avoid fencepost error for index k.
TL = size(tArray)-1;


% xLocation = all values in the first row of all values in the first
% column of vortexArray, or IN OTHER WORDS, xLocation is
% a line of all values in the first column of vortexArray.
xLocation(1,:) = vortexArray(:,1);

% yLocation is all values in the first column of vortexArray.
yLocation(1,:) = vortexArray(:,2);

% loop to use equations for each interval in the timestep k.
for k = 1:TL
    
    
    % velocityArray uses vortexVelocity function on vortexArray to
    % produce an array of u and v velocity vectors of vortices.
    velocityArray = vortexVelocity(vortexArray);
    
    % T is just the interval in the timestep (.01) in this case.
    T = tArray(k+1) - tArray(k);
    
    
    % another for loop to go down the list of u/v vectors
    % to determine the x and y positions of the velocity vectors of
    % each vortex.
    
    for i = 1:size(velocityArray,1);
        
        % velocityArray produces 2 columns, u and v, so now
        % separating u and v into individual values.
        u = velocityArray(i,1);
        v = velocityArray(i,2);
        
        % equations to determine position based on time and velocity
        % vector.
        xLocation(k+1,i) = u*T + xLocation(k,i);
        yLocation(k+1,i) = v*T + yLocation(k,i);
        
        % overwriting vortexArray to now be an array of new positions
        % for velocities.
        vortexArray(i,1) = xLocation(k+1,i);
        vortexArray(i,2) = yLocation(k+1,i);
    end
end

% plot commands for each row of x/y velocity positions


for i = 1:size(vortexArray,1)
    plot(xLocation(:,i), yLocation(:,i))
    hold on
    axis equal
    xlabel ('x')
    ylabel ('y')
    title ('Vortices Near a Wall')
end